==> phpnuke-5.5.tgz: www/phpnuke/html/modules/News/language/lang-swedish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_SEND","Skicka");
define("_URL","URL");
define("_PRINTER","Utskriftsvnlig sida");
define("_FRIEND","Skicka denna artikel till en kompis");
define("_YOURNAME","Ditt Namn");
define("_OK","Ok!");
define("_RELATED","Relaterade Lnkar");
define("_MOREABOUT","Mer om");
define("_NEWSBY","Artiklar av");
define("_MOSTREAD","Mest lsta artikel om");
define("_READMORE","Ls mer...");
define("_BYTESMORE","bytes mer");
define("_COMMENTSQ","kommentarer?");
define("_COMMENT","kommentar");
define("_CONFIGURE","Konfigurera");
define("_LOGINCREATE","Logga in/Skapa ett konto");
define("_THRESHOLD","Trskel");
define("_NOCOMMENTS","Inga kommentarer");
define("_NESTED","Nstlad");
define("_FLAT","Platt");
define("_THREAD","Trdad");
define("_OLDEST","ldst Frst");
define("_NEWEST","Nyaste Frst");
define("_HIGHEST","Hgsta pong frst");
define("_COMMENTSWARNING","Kommentarern gs av respektive postare. Vi tar inte ansvar fr innehllet i dem.");
define("_SCORE","Pong:");
define("_USERINFO","Anvndarinformation");
define("_READREST","Lst resten av denna kommentar...");
define("_REPLY","Svara p detta");
define("_REPLYMAIN","Posta kommentar");
define("_NOSUBJECT","Inget mne");
define("_NOANONCOMMENTS","Inga kommentarer tillts fr anonyma beskare, vnligen <a href=\"modules.php?name=Your_Account\">registrera dig</a>");
define("_PARENT","Frlder");
define("_ROOT","Root");
define("_UCOMMENT","Kommentar");
define("_ALLOWEDHTML","Tillten HTML:");
define("_POSTANON","Posta Anonymt");
define("_EXTRANS","Extrans (html kod till text)");
define("_HTMLFORMATED","HTML Formaterad");
define("_PLAINTEXT","Helt vanlig text");
define("_ONN","p...");
define("_SUBJECT","mne");
define("_COMMENTREPLY","Posta Kommentar");
define("_COMREPLYPRE","Frhandsgranska Kommentar");
define("_NOTRIGHT","Nnting gick t skogen nr vi skickade med en variabel till den hr funktionen. Det hr meddelandet finns hr bara fr att inte stlla till det mer lngre ner.");
define("_SENDAMSG","Skicka ett meddelande");
define("_YOUSENDSTORY","Du kommer att skicka artikeln");
define("_TOAFRIEND","till en specificerad kompis:");
define("_FYOURNAME","Ditt Namn:");
define("_FYOUREMAIL","Din E-postadress:");
define("_FFRIENDNAME","Din Kompis Namn:");
define("_FFRIENDEMAIL","Din Kompis E-postadress:");
define("_INTERESTING","Intressant Artikel p");
define("_HELLO","Hej");
define("_YOURFRIEND","Din kompis");
define("_CONSIDERED","tyckte att fljande artikel var intressant och ville skicka den till dig.");
define("_FDATE","Datum:");
define("_FTOPIC","mne:");
define("_YOUCANREAD","Du kan lsa fler intressanta artiklar p");
define("_FSTORY","Artikeln");
define("_HASSENT","Har skickats till");
define("_THANKS","Tack!");
define("_RECOMMEND","Rekommendera denna webbplats till en kompis");
define("_PDATE","Datum:");
define("_PTOPIC","mne:");
define("_COMESFROM","Den hr artikeln kommer frn");
define("_THEURL","Adressen till denna artikel r:");
define("_PREVIEW","Frhandsgranska");
define("_NEWUSER","Ny medlem");
define("_OPTIONS","Alternativ");
define("_REFRESH","Uppdatera");
define("_ADD","Addera");
define("_NOCOMMENTSACT","Sorry, Comments are not available for this article.");
define("_ARTICLEPOLL","Article's Poll");
define("_RATEARTICLE","Article Rating");
define("_RATETHISARTICLE","Please take a second and vote for this article:");
define("_CASTMYVOTE","Cast my Vote!");
define("_AVERAGESCORE","Average Score");
define("_BAD","Bad");
define("_REGULAR","Regular");
define("_GOOD","Good");
define("_VERYGOOD","Very Good");
define("_EXCELLENT","Excellent");
define("_ARTICLERATING","Article Rating");
define("_THANKSVOTEARTICLE","Thanks for voting for this article!");
define("_ALREADYVOTEDARTICLE","Sorry, you already voted for this article recently!");
define("_BACKTOARTICLEPAGE","Back to Article's Page");
define("_DIDNTRATE","You didn't selected any score for the article!");
define("_NOINFO4TOPIC","Sorry, there isn't information for the selected topic.");
define("_GOTONEWSINDEX","Go to News Index");
define("_SELECTNEWTOPIC","Select a New Topic");
define("_GOTOHOME","Go to Home");
define("_SEARCHONTOPIC","Search on This Topic");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/News/language/lang-swedish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_SEND","Skicka");
define("_URL","URL");
define("_PRINTER","Utskriftsvnlig sida");
define("_FRIEND","Skicka denna artikel till en kompis");
define("_YOURNAME","Ditt Namn");
define("_OK","Ok!");
define("_RELATED","Relaterade Lnkar");
define("_MOREABOUT","Mer om");
define("_NEWSBY","Artiklar av");
define("_MOSTREAD","Mest lsta artikel om");
define("_READMORE","Ls mer...");
define("_BYTESMORE","bytes mer");
define("_COMMENTSQ","kommentarer?");
define("_COMMENT","kommentar");
define("_CONFIGURE","Konfigurera");
define("_LOGINCREATE","Logga in/Skapa ett konto");
define("_THRESHOLD","Trskel");
define("_NOCOMMENTS","Inga kommentarer");
define("_NESTED","Nstlad");
define("_FLAT","Platt");
define("_THREAD","Trdad");
define("_OLDEST","ldst Frst");
define("_NEWEST","Nyaste Frst");
define("_HIGHEST","Hgsta pong frst");
define("_COMMENTSWARNING","Kommentarern gs av respektive postare. Vi tar inte ansvar fr innehllet i dem.");
define("_SCORE","Pong:");
define("_USERINFO","Anvndarinformation");
define("_READREST","Lst resten av denna kommentar...");
define("_REPLY","Svara p detta");
define("_REPLYMAIN","Posta kommentar");
define("_NOSUBJECT","Inget mne");
define("_NOANONCOMMENTS","Inga kommentarer tillts fr anonyma beskare, vnligen <a href=\"modules.php?name=Your_Account\">registrera dig</a>");
define("_PARENT","Frlder");
define("_ROOT","Root");
define("_UCOMMENT","Kommentar");
define("_ALLOWEDHTML","Tillten HTML:");
define("_POSTANON","Posta Anonymt");
define("_EXTRANS","Extrans (html kod till text)");
define("_HTMLFORMATED","HTML Formaterad");
define("_PLAINTEXT","Helt vanlig text");
define("_ONN","p...");
define("_SUBJECT","mne");
define("_COMMENTREPLY","Posta Kommentar");
define("_COMREPLYPRE","Frhandsgranska Kommentar");
define("_NOTRIGHT","Nnting gick t skogen nr vi skickade med en variabel till den hr funktionen. Det hr meddelandet finns hr bara fr att inte stlla till det mer lngre ner.");
define("_SENDAMSG","Skicka ett meddelande");
define("_YOUSENDSTORY","Du kommer att skicka artikeln");
define("_TOAFRIEND","till en specificerad kompis:");
define("_FYOURNAME","Ditt Namn:");
define("_FYOUREMAIL","Din E-postadress:");
define("_FFRIENDNAME","Din Kompis Namn:");
define("_FFRIENDEMAIL","Din Kompis E-postadress:");
define("_INTERESTING","Intressant Artikel p");
define("_HELLO","Hej");
define("_YOURFRIEND","Din kompis");
define("_CONSIDERED","tyckte att fljande artikel var intressant och ville skicka den till dig.");
define("_FDATE","Datum:");
define("_FTOPIC","mne:");
define("_YOUCANREAD","Du kan lsa fler intressanta artiklar p");
define("_FSTORY","Artikeln");
define("_HASSENT","Har skickats till");
define("_THANKS","Tack!");
define("_RECOMMEND","Rekommendera denna webbplats till en kompis");
define("_PDATE","Datum:");
define("_PTOPIC","mne:");
define("_COMESFROM","Den hr artikeln kommer frn");
define("_THEURL","Adressen till denna artikel r:");
define("_PREVIEW","Frhandsgranska");
define("_NEWUSER","Ny medlem");
define("_OPTIONS","Alternativ");
define("_REFRESH","Uppdatera");
define("_ADD","Addera");
define("_NOCOMMENTSACT","Sorry, Comments are not available for this article.");
define("_ARTICLEPOLL","Article's Poll");
define("_RATEARTICLE","Article Rating");
define("_RATETHISARTICLE","Please take a second and vote for this article:");
define("_CASTMYVOTE","Cast my Vote!");
define("_AVERAGESCORE","Average Score");
define("_BAD","Bad");
define("_REGULAR","Regular");
define("_GOOD","Good");
define("_VERYGOOD","Very Good");
define("_EXCELLENT","Excellent");
define("_ARTICLERATING","Article Rating");
define("_THANKSVOTEARTICLE","Thanks for voting for this article!");
define("_ALREADYVOTEDARTICLE","Sorry, you already voted for this article recently!");
define("_BACKTOARTICLEPAGE","Back to Article's Page");
define("_DIDNTRATE","You didn't selected any score for the article!");
define("_NOINFO4TOPIC","Sorry, there isn't information for the selected topic.");
define("_GOTONEWSINDEX","Go to News Index");
define("_SELECTNEWTOPIC","Select a New Topic");
define("_GOTOHOME","Go to Home");
define("_SEARCHONTOPIC","Search on This Topic");

?>
